@@ -29,14 +29,30 @@ def generic_callback(response_bytes, payload, log_level, figsize):
     """
     results = []
     response = json.loads(response_bytes.decode())
+
     if log_level == DEBUG_LEVEL:
         print(response)
+
+    if ("AuthStatus" not in response): # [EXPW-1446]
+        if ("Error" in response):
+            raise exceptions.AuthenticationException(response["Error"]) # [EXPW-1446]
+        else:
+            raise exceptions.AuthenticationException("Virtualitics Explore failed to authenticate the session. AuthStatus could not be found.") # [EXPW-1446]
+
+    if ("VersionStatus" not in response): # [EXPW-1446]
+        if ("Error" in response):
+            raise exceptions.AuthenticationException(response["Error"]) # [EXPW-1446]
+        else:
+            raise exceptions.AuthenticationException("Virtualitics Explore failed to authenticate the session. VersionStatus could not be found.") # [EXPW-1446]
+
     if (response["AuthStatus"] == "Success") and (response["VersionStatus"] == "Success"):
         if "SpecialResponse" in response:
             print(response["SpecialResponse"] + "\n")
             return None, None
+
         task_failures = []
         task_index = 1
+
         for task_response in response["TaskResponses"]:
             task_status = task_response.get("TaskStatus") or "Failed"
             if task_status != "Success":
@@ -55,6 +71,7 @@ def generic_callback(response_bytes, payload, log_level, figsize):
             error = failure.get('Error') or '(unknown reason)'
             error = error.replace('\n', '').replace('<b>', '').replace('</b>', '').strip()
             exception_message = "Task '%s' failed because '%s'" % (task_type, error)
+
             if (task_type == "unknown") and (error == "(unknown reason)"):
                 raise exceptions.VipTaskUnknownExecutionException("The Virtualitics Explore task execution failed without providing a "
                                                                   "reason. Please try running the command again. ")
@@ -62,6 +79,7 @@ def generic_callback(response_bytes, payload, log_level, figsize):
             if "Note" in failure:
                 note = failure["Note"].replace('\n', '').replace('<b>', '').replace('</b>', '').strip()
                 exception_message += ". Note: '%s'" % note
+
             raise exceptions.VipTaskExecutionException(exception_message)
 
         if len(results) == 0:
@@ -172,6 +190,8 @@ def _process_specific_task(task_response, payload, log_level, figsize):
         return _get_workflow_callback(task_response, payload)
     elif task_type == "GetLegend":
         return _get_legend_callback(task_response, payload)
+    elif task_type == "GetOrientation":
+        return _get_orientation_callback(task_response, payload)
 
     notes_message = ""
     if "Note" in task_response:
@@ -192,7 +212,8 @@ def _plot_mapping_export_callback(task_response, payload, log_level):
     :param log_level: logging level used in the callbacks to set in returned vip plot
     :return: :class:`VipPlot` object instance
     """
-    if not task_response["SaveToLocalHistory"] and not task_response["ReturnPlotMapping"]:
+    if ((not task_response["SaveToLocalHistory"] or not isinstance(task_response["SaveToLocalHistory"], bool) or task_response["SaveToLocalHistory"] == False) and
+        (not task_response["ReturnPlotMapping"] or not isinstance(task_response["ReturnPlotMapping"], bool) or task_response["ReturnPlotMapping"] == False)):
         return None
 
     plot = vip_plot.VipPlot(data_set_name=task_response["DataSetName"], plot_type=task_response["PlotType"],
@@ -571,6 +592,11 @@ def _plot_mapping_export_callback(task_response, payload, log_level):
             plot.z_limit_link = bool(plotSettings["ZLimitLink"].lower() == "true")
         except:
             pass
+    if "EdgeTransparency" in plotSettings.keys() and plotSettings["EdgeTransparency"] is not None:
+        try:
+            plot.edge_transparency = float(plotSettings["EdgeTransparency"])
+        except:
+            pass
 
     notes_message = ""
     if "Note" in task_response:
@@ -588,6 +614,14 @@ def _crop_plot(img):
     pixel_first = img_array[0,0]
     pix_match = np.all(img_array == pixel_first, axis=2)
     rows, cols = np.where(pix_match == False)
+
+    #print("Rows: ", rows, "Cols: ", cols) #[DEBUG]
+
+    # Not enough data or variation in pixel color to do an auto-crop. This happens when the plot is outside of camera view and all the pixels in the original image are the same color.
+    # Can happen after adding support for custom plot transform values -> [EXPD-1993]
+    if (rows is None or cols is None or len(rows) <= 0 or len(cols) <= 0):
+        return img; # Return the original image to avoid any errors.
+
     min_row = max(np.min(rows) - margin_top, 0)
     max_row = min(np.max(rows) + margin_top, img_array.shape[0] - 1)
     min_col = max(np.min(cols) - margin_side, 0)
@@ -622,7 +656,10 @@ def _export_callback(task_response, payload, figsize):
             if "Path" in task_response.keys():
                 image.save(task_response["Path"], quality=100)
 
-        return None
+    if "Note" in task_response:
+        print("Note: '%s'\n" % task_response["Note"].replace('\n', '').replace('<b>', '').replace('</b>', '').strip())
+
+    return None
 
 
 def _smart_mapping_callback(task_response, payload):
@@ -1085,3 +1122,9 @@ def _get_legend_callback(task_response, payload):
         return json.loads(task_response["Legend"])
 
     return None
+
+def _get_orientation_callback(task_response, payload):
+    if "Transforms" in task_response:
+        return task_response["Transforms"]
+
+    return None
