@@ -101,10 +101,8 @@ PIVOT_TYPES = {"min": "Min", "max": "Max", "mean": "Mean", "median": "Median",
 HEATMAP_RADIUS_UNITS = {"kilometers": "Kilometers", "km": "Kilometers", "miles": "Miles", "mi": "Miles",
                         "nauticalmiles": "NauticalMiles", "nm": "NauticalMiles"}
 STR_COL_DELIMETER = '\x01'
-EXPLAINABLE_AI_FUNCTION = {"identificationtree": "IdentificationTree", "id_tree" : "IdentificationTree", 
-                            "categorybreakdown": "CategoryBreakdown", "categories": "CategoryBreakdown", 
-                            "relativeedgedensity": "RelativeEdgeDensity", "edges" : "RelativeEdgeDensity",
-                            "kolmogorovsmirnov" : "KolmogorovSmirnov", "kolmogorovsmirnov_test" : "KolmogorovSmirnov", "ks_test" : "KolmogorovSmirnov"}
+EXPLAINABLE_AI_FUNCTION = {"identificationtree": "IdentificationTree", "relativeedgedensity": "RelativeEdgeDensity",
+                           "kolmogorovsmirnov" : "KolmogorovSmirnov"}
 
 def case_insensitive_match(d: dict, val, var_name: str):
     """
